Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'js/piwik.js')
-rw-r--r--js/piwik.js5
1 files changed, 3 insertions, 2 deletions
diff --git a/js/piwik.js b/js/piwik.js
index f537d2014a..ea4f8dfa54 100644
--- a/js/piwik.js
+++ b/js/piwik.js
@@ -957,7 +957,7 @@ if (typeof JSON_PIWIK !== 'object' && typeof window.JSON === 'object' && window.
/*global unescape */
/*global ActiveXObject */
/*global Blob */
/*members Piwik, encodeURIComponent, decodeURIComponent, getElementsByTagName,
shift, unshift, piwikAsyncInit, piwikPluginAsyncInit, frameElement, self, hasFocus,
createElement, appendChild, characterSet, charset, all,
addEventListener, attachEvent, removeEventListener, detachEvent, disableCookies,
@@ -1053,7 +1053,7 @@ if (typeof _paq !== 'object') {
// Piwik singleton and namespace
if (typeof window.Piwik !== 'object') {
- window.Piwik = (function () {
+ window.Matomo = window.Piwik = (function () {
'use strict';
/************************************************************
@@ -7670,6 +7670,7 @@ if (typeof window.Piwik !== 'object') {
// Expose Piwik as an AMD module
if (typeof define === 'function' && define.amd) {
define('piwik', [], function () { return Piwik; });
+ define('matomo', [], function () { return Piwik; });
}
return Piwik;
@@ -957,7 +957,7 @@ if (typeof JSON_PIWIK !== 'object' && typeof window.JSON === 'object' && window.
/*global ActiveXObject */
/*global Blob */
-/*members Piwik, encodeURIComponent, decodeURIComponent, getElementsByTagName,
+/*members Piwik, Matomo, encodeURIComponent, decodeURIComponent, getElementsByTagName,
shift, unshift, piwikAsyncInit, piwikPluginAsyncInit, frameElement, self, hasFocus,
createElement, appendChild, characterSet, charset, all,